@@ -1,10 +1,8 @@
 from django.conf.urls.defaults import *
-from django.contrib.auth.urls import urlpatterns as user_urlpatterns
 
-from user.views import SignUpView
+from user.views import SignInView, SignUpView
 
 urlpatterns = patterns('',
+    url(r'^sign-in/$', SignInView.as_view(template_name='user/sign_in.html'), name='sign_in'),
     url(r'^sign-up/$', SignUpView.as_view(template_name='user/sign_up.html'), name='sign_up'),
 )
-
-urlpatterns += user_urlpatterns
\ No newline at end of file
